@@ -30,7 +30,7 @@ namespace satellites {
 class SATELLITES_API phase_unwrap : virtual public gr::sync_block
 {
 public:
-    typedef boost::shared_ptr<phase_unwrap> sptr;
+    typedef std::shared_ptr<phase_unwrap> sptr;
 
     /*!
      * \brief Build the Phase Unwrap block
