@@ -12,6 +12,7 @@ from gnuradio import gr, blocks
 
 from ... import pdu_to_kiss
 from ...utils.options_block import options_block
+from ...grtypes import byte_t
 
 
 class kiss_file_sink(gr.hier_block2, options_block):
@@ -41,7 +42,7 @@ class kiss_file_sink(gr.hier_block2, options_block):
 
         self.kiss = pdu_to_kiss(include_timestamp=True,
                                 initial_timestamp=initial_timestamp)
-        self.pdu2tag = blocks.pdu_to_tagged_stream(blocks.byte_t, 'packet_len')
+        self.pdu2tag = blocks.pdu_to_tagged_stream(byte_t, 'packet_len')
         self.filesink = blocks.file_sink(gr.sizeof_char, file, append)
 
         self.connect(self.pdu2tag, self.filesink)
