@@ -13,6 +13,8 @@ from gnuradio import blocks
 from gnuradio import digital
 from gnuradio import gr
 from gnuradio.filter import firdes
+from ..grpdu import pdu_to_tagged_stream, tagged_stream_to_pdu
+from ..grtypes import byte_t
 
 
 class ccsds_descrambler(gr.hier_block2):
@@ -35,12 +37,12 @@ class ccsds_descrambler(gr.hier_block2):
         self.blocks_unpacked_to_packed_xx_0_0_0_0 = (
             blocks.unpacked_to_packed_bb(1, gr.GR_MSB_FIRST))
         self.blocks_tagged_stream_to_pdu_0_0_0_0_0 = (
-            blocks.tagged_stream_to_pdu(blocks.byte_t, 'packet_len'))
+            tagged_stream_to_pdu(byte_t, 'packet_len'))
         self.blocks_tagged_stream_multiply_length_0_0_0_0 = (
             blocks.tagged_stream_multiply_length(
                 gr.sizeof_char*1, 'packet_len', 1/8.0))
         self.blocks_pdu_to_tagged_stream_0 = (
-            blocks.pdu_to_tagged_stream(blocks.byte_t, 'packet_len'))
+            pdu_to_tagged_stream(byte_t, 'packet_len'))
 
         ##################################################
         # Connections
