@@ -41,7 +41,7 @@ class ngham_remove_padding(gr.basic_block):
         if not pmt.is_u8vector(msg):
             print('[ERROR] Received invalid message type. Expected u8vector')
             return
-        packet = bytes(pmt.u8vector_elements(msg))
+        packet = pmt.u8vector_elements(msg)
 
         if len(packet) in ngham_rs_sizes:
             size_idx = ngham_rs_sizes.index(len(packet))
