@@ -35,7 +35,7 @@ class reflect_bytes(gr.basic_block):
         packet = np.array(pmt.u8vector_elements(msg), dtype='uint8')
         packet = np.unpackbits(packet)
         packet = reflect(packet)
-        packet = bytes(np.packbits(packet))
+        packet = np.packbits(packet)
 
         self.message_port_pub(
             pmt.intern('out'),
