@@ -8,17 +8,17 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
 
-import numpy
 from gnuradio import gr
+import numpy
 import pmt
 
+
 class swiatowid_packet_crop(gr.basic_block):
-    """
-    docstring for block swiatowid_packet_crop
-    """
+    """docstring for block swiatowid_packet_crop"""
     def __init__(self):
-        gr.basic_block.__init__(self,
-            name="swiatowid_packet_crop",
+        gr.basic_block.__init__(
+            self,
+            name='swiatowid_packet_crop',
             in_sig=[],
             out_sig=[])
 
@@ -29,12 +29,16 @@ class swiatowid_packet_crop(gr.basic_block):
     def handle_msg(self, msg_pmt):
         msg = pmt.cdr(msg_pmt)
         if not pmt.is_u8vector(msg):
-            print("[ERROR] Received invalid message type. Expected u8vector")
+            print('[ERROR] Received invalid message type. Expected u8vector')
             return
-        packet = bytes(pmt.u8vector_elements(msg))
+        packet = pmt.u8vector_elements(msg)
 
         packet_length = packet[0] + packet[1] * 256 - 8
         if packet_length + 2 > len(packet):
             return
-                
-        self.message_port_pub(pmt.intern('out'),  pmt.cons(pmt.car(msg_pmt), pmt.init_u8vector(packet_length, packet[2:2+packet_length])))
+
+        self.message_port_pub(
+            pmt.intern('out'),
+            pmt.cons(
+                pmt.car(msg_pmt),
+                pmt.init_u8vector(packet_length, packet[2:2+packet_length])))
