@@ -25,8 +25,13 @@ from .ax25 import ax25
 from .binar1 import binar1
 from .by02 import by02
 from .by70_1 import by70_1
+from .cirbe_70cm import cirbe_70cm
 from .csp import csp
+from .csp import cspv2
+from .ctim_70cm import ctim_70cm
 from .cute_70cm import cute_70cm
+from .delfic3 import delfic3
+from .delfipq import delfipq
 from .dstar_one import dstar_one
 from .eseo import eseo
 from .floripasat import floripasat
@@ -35,6 +40,7 @@ from .fossasat_2 import fossasat_2
 from .funcube import funcube
 from .gomx_1 import gomx_1
 from .gomx_3 import gomx_3
+from .inspiresat_1 import inspiresat_1
 from .kr01 import kr01
 from .lume import lume
 from .mirsat1 import mirsat1
